function [f,fx,fy,delta] = choosefun(funind)
%CHOOSEFUN choose test function for a synthetic observed object.
%   [f,fx,fy,delta]=choosefun(funind) returns the function, the partial
%   derivatives, and the Laplacian, as function handles given an index
%   funind between 1 and 5.
%
%   See also datasynth, testsynth, and testshell.

%   A. Concas, R. Dessì, C. Fenu, G. Rodriguez & M. Vanzi
%   Email: concas.anna@gmail.com, richidessi@gmail.com, kate.fenu@unica.it, 
%   rodriguez@unica.it, vanzi@diee.unica.it
%
%   Last revised June, 2021

switch funind

case 1
	f = @(x,y) 1 - x.^2 - y.^2;
	fx = @(x,y) -2*x;
	fy = @(x,y) -2*y;
	delta = @(x,y) -4*ones(size(x,1),size(x,2));

case 2
	f = @(x,y) 0.5*exp(x).*sin(pi*x).*sin(pi*y);
	fx = @(x,y) 0.5*exp(x).*(sin(pi*x)+pi*cos(pi*x)).*sin(pi*y);
	fy = @(x,y) 0.5*pi*exp(x).*sin(pi*x).*cos(pi*y);
	delta = @(x,y) 0.5*exp(x).*((1-2*pi^2)*sin(pi*x)+2*pi*cos(pi*x)).*sin(pi*y);

case 3
	k = .8;
	r = 1.1;
	f = @(x,y) (real(sqrt(r^2-x.^2-y.^2))-r*sqrt(1-k^2)).*(x.^2+y.^2<=(k*r)^2);
	fx = @(x,y) real(-x./sqrt(r^2-x.^2-y.^2)).*(x.^2+y.^2<=(k*r)^2);
	fy = @(x,y) real(-y./sqrt(r^2-x.^2-y.^2)).*(x.^2+y.^2<=(k*r)^2);
	delta = @(x,y) nan*ones(size(x,1),size(x,2));	% still to be computed

case 4
	f = @(x,y) 2*x+y;
	fx = @(x,y) 2;
	fy = @(x,y) 1;
	delta = @(x,y) zeros(size(x,1),size(x,2));

case 5
	f = @(x,y) -(x+y)/10.*((x>=-2/3)&(x<=2/3)&(y>=-2/3)&(y<=2/3));
	fx = @(x,y) -ones(size(x,1),size(y,2))/10.*((x>=-2/3)&(x<=2/3)&(y>=-2/3)&(y<=2/3));
	fy = @(x,y) -ones(size(x,1),size(y,2))/10.*((x>=-2/3)&(x<=2/3)&(y>=-2/3)&(y<=2/3));
	delta = @(x,y) zeros(size(x,1),size(x,2));

otherwise
	error('Invalid example index.')
end

