function L = createlights(angles, z)
%CREATELIGHTS create the lights matrix.
%   L = createlights(angles,z) create the light sources matrix by setting the
%   angles and the z coordinates for each light source.
%
%   See also datasynth, testsynth, and testshell.

%   A. Concas, R. Dessì, C. Fenu, G. Rodriguez & M. Vanzi
%   Email: concas.anna@gmail.com, richidessi@gmail.com, kate.fenu@unica.it, 
%   rodriguez@unica.it, vanzi@diee.unica.it
%
%   Last revised June, 2021

q = size(angles(:),1);
if nargin<2, z = [ones(1,q-1),1.5]; end	% z's cannot be all 1!

if all(z==z(1)), warning('The unknown lights problem will be rank deficient!'), end

L = zeros(3,q);
for j = 1:q
	L(:,j) = [cos(angles(j)); sin(angles(j)); z(j)];
	L(:,j) = L(:,j)/norm(L(:,j));
end
L(abs(L)<sqrt(eps)) = 0;

