% create synthetic data set, use funind to select example.

% initialization
fsiz = 12;		% font size for figures
displayfactor = 1;	% for displaying images on screen
nrow = 3; ncol = 3;	% grid for figure 2

A = 2;			% horizontal size of image in meters (or cm, ...)
funind = 2;		% test function index
albedotype = 2;		% test albedo index
r = 101;		% horizontal size of image in pixels
s = 101;		% vertical size of image in pixels

[f,fx,fy,delta] = choosefun(funind);

% set angles for lights:
angles = [0 pi/4 3/4*pi pi 5/4*pi 3/2*pi 7/4*pi];	% 7 lights
% set z coordinate for lights
z = [ones(1,numel(angles)-1),1.5];
Ltrue = createlights(angles,z);

% compute constants
p = r*s;		% pixels number
q = size(Ltrue,2);	% lights number

fprintf('images size  : %d X %d\n',r,s)
fprintf('problem size : %d\n',p)
fprintf('images number: %d\n',q)

plotlights3d(Ltrue,3,fsiz)
title('original light directions')

Ltrueh = Ltrue;
%Ltrueh = [Ltrue;1e-4*ones(1,q)];	% in homogeneous coordinates

Rho = makealbedo(albedotype,r,s);
[M,XX,YY,Z,Ntrue,h,B] = makeimage(f,fx,fy,r,s,A,Ltrueh,Rho);

if funind == 3		% clean NaN's in test function 3
	warning('Cleaning NaN''s from data.')
	mm = M(:);
	mm(isnan(mm)) = M(1,1);
	M = reshape(mm,p,q);
	vv = find(isnan(Ntrue(1,:)));
	Ntrue(:,vv) = Ntrue(:,vv-1);
end

figure(1)
clf
surfl(XX,YY,Z)
colormap gray
shading interp
axis equal
set(gca,'fontsize',fsiz)
title('Model surface')

figure(2)
clf
fprintf('displaying images:')
for i = 1:q
	fprintf(' %d',i)
	figure(2)
	subplot(nrow,ncol,i)
	pcolor(imresize(reshape(M(:,i),s,r),displayfactor))
	colormap gray
	shading interp
	axis image
	axis off
	%pause
end
fprintf('\n')

