function R = makealbedo(type,r,s)
%MAKEALBEDO create an albedo matrix.
%   R = makealbedo(type,r,s) create the albedo matrix of size s x r.
%   type can be 1 (all ones) or 2 (a gray centered circle).
%
%   See also datasynth, testsynth, and testshell.

%   A. Concas, R. Dessì, C. Fenu, G. Rodriguez & M. Vanzi
%   Email: concas.anna@gmail.com, richidessi@gmail.com, kate.fenu@unica.it, 
%   rodriguez@unica.it, vanzi@diee.unica.it
%
%   Last revised June, 2021

switch type

case 1
	R = ones(s,r); 

case 2
	R = ones(s,r); 
%	xc = round(r/2);
%	yc = round(s/2);
	x = linspace(-1,1,r);
	y = linspace(-1,1,s);
	[X,Y] = meshgrid(x,y);
	r = 1/2;
	R((X.^2+Y.^2)<r^2) = 0.5;

otherwise
	error('Unknown albedo type.')
end

