function [U,A] = poisdir(F,h)
%POISDIR Poisson solver with homogeneous Dirichlet boundary conditions.
%   U = poidir(F,h) solves the Poisson equation ΔU = F by solving a linear
%   system with coefficient matrix A obtained by a five point scheme
%   discretization with stepsize h.
%
%   See also ps3dstep2.

%   A. Concas, R. Dessì, C. Fenu, G. Rodriguez & M. Vanzi
%   Email: concas.anna@gmail.com, richidessi@gmail.com, kate.fenu@unica.it, 
%   rodriguez@unica.it, vanzi@diee.unica.it
%
%   Last revised June, 2021

[n,m] = size(F);
m = m-2;
n = n-2;

%T = sparse(toeplitz([-4 1 zeros(1,n-2)]));
T = spdiags(ones(n,1)*[1 -4 1],[-1,0,1],n,n);
In = speye(n);
Im = speye(m);
%S = sparse(toeplitz([0 1 zeros(1,m-2)]));
S = spdiags(ones(m,2),[-1,1],m,m);
A = kron(Im,T)+kron(S,In);

f = reshape(F(2:n+1,2:m+1),m*n,1);
u = A\f;
u = h^2*u;
U = zeros(n+2,m+2);
U(2:n+1,2:m+1) = reshape(u,n,m);

