function [U,X,Y,D,N,L,P,Q] = ps3d( M, r, s, A, light2, show, fsiz, bcond, bdata)
%PS3D	photometric stereo 3D reconstruction.
%   [U,X,Y] = ps3d(M,r,s,A) returns the 3D coordinates of the observed objects,
%   where M contains in each column an image of the object of size rXs with
%   different lighting and A is the length of the horizontal axis.
%   The pictures must be shot from the same point of view, turning the light
%   counter-clockwise around the object starting at east.
%   At least 6 pictures are required, the more the better.
%   [U,X,Y,D,N,L,P,Q]=ps3d(...) optionally returns the albedo D, the normal
%   vectors N, the light vectors L, and the component of the gradients P and Q.

%   A. Concas, R. Dessì, C. Fenu, G. Rodriguez & M. Vanzi
%   Email: concas.anna@gmail.com, richidessi@gmail.com, kate.fenu@unica.it, 
%   rodriguez@unica.it, vanzi@diee.unica.it
%
%   Last revised June, 2021

if nargin<9, bdata = {}; end
if nargin<8, bcond = 1; end
if nargin<7, fsiz = 10; end
if nargin<6, show = 0; end
if nargin<5, light2 = 0; end

if min(min(M)) == 0
	warning('Adding sqrt(eps) to zero data points.')
	M(M==0) = sqrt(eps);
end

[D,N,L,NT] = ps3dstep1( M, r, s, light2, show, fsiz);
[U,X,Y,P,Q] = ps3dstep2( NT, r, s, A, bcond, bdata);

