function [N,L,Q] = rotatelights( N, L, light2)
%ROTATELIGHTS finds the rotation of the recovered lights. 
%   auxiliary function called by ps3dstep1.
%
% See also ps3dstep1.

%   A. Concas, R. Dessì, C. Fenu, G. Rodriguez & M. Vanzi
%   Email: concas.anna@gmail.com, richidessi@gmail.com, kate.fenu@unica.it, 
%   rodriguez@unica.it, vanzi@diee.unica.it
%
%   Last revised June, 2021

if nargin<3, light2 = 0; end

q = size(L,2);

lorient = det(L(:,[1 floor(q/3) floor(2*q/3)]));
if lorient < 0
	N(3,:) = -N(3,:);
	L(3,:) = -L(3,:);
end

if light2 > 0				% direction of the camera
	zv = L(:,[1 light2])*ones(2,1); zv = zv/norm(zv);
else					% average of lights directions
	zv = L*ones(q,1); zv = zv/norm(zv);
end
projs = L'*zv;
if any(projs < 0), error('We still have to manage this.'), end

xv = L(:,1) - (zv'*L(:,1))*zv;		% projection of first light
xv = xv/norm(xv);			% on the object plane
yv = [det([zv(2:3),xv(2:3)]); -det([zv([1,3]),xv([1,3])]); ...
	det([zv(1:2),xv(1:2)])];	% determined by orthogonality
yv = yv/norm(yv);
Q = [xv yv zv]';
N = Q*N;
L = Q*L;
if lorient < 0, Q(:,3) = -Q(:,3); end	% ???

