% process the synthetic dataset.

% initialization
econ = 0;		% clean memory
show = 1;		% disable for large datasets
fsiz = 12;		% font size for figures
scalefactor = 1;	% to reduce size of images 
displayfactor = 1;	% for displaying images on screen
nrow = 3; ncol = 3;	% grid for figure 2

A = 2;			% horizontal size of image in meters (or cm, ...)
funind = 2;		% test function index
albedotype = 2;		% test albedo index
r = 101;		% horizontal size of image in pixels
s = 101;		% vertical size of image in pixels

[f,fx,fy,delta] = choosefun(funind);

bcond = 1;	% 1 for Dirichlet, 2 for Neumann

% set angles for lights:
% angles(1) is the light at east, angles(light2) is the light at west
%angles = [0:pi/2:3/2*pi]; light2 = 3;				% 4 lights
%angles = [pi/4:pi/2:2*pi]
%angles = [0:2*pi/5:4*2*pi/5];
%angles = [0:2*pi/6:5*2*pi/6]; light2 = 4;			% 6 lights
%angles = [0 pi/4 pi 3/2*pi];
%angles = [0 pi/4 pi 5/4*pi 3/2*pi]; light2 = 3;		% 5 lights
%angles = [0 pi/4 3/4*pi pi 5/4*pi 3/2*pi]; light2 = 4;		% 6 lights
angles = [0 pi/4 3/4*pi pi 5/4*pi 3/2*pi 7/4*pi]; light2 = 4; 	% 7 lights
%angles = [0:pi/4:7/4*pi]; light2 = 5;				% 8 lights

% set z coordinate for lights
z = [ones(1,numel(angles)-1),1.5];

% perturbate lights position, except for the two reference lights
ds = 0;
%ds = 0.1;
%noise = ds*randn(1,numel(angles));
%if light2>0, noise([1 light2]) = 0; end

Ltrue = createlights(angles,z);
%Ltrue = createlights(angles+noise,z+noise);

% compute constants
p = r*s;		% pixels number
q = size(Ltrue,2);	% lights number

fprintf('images size  : %d X %d\n',r,s)
fprintf('problem size : %d\n',p)
fprintf('images number: %d\n',q)

%plotlights(Ltrue,3)
%title('original light directions')
plotlights3d(Ltrue,5,fsiz)
title('original light directions')

Ltrueh = Ltrue;
%Ltrueh = [Ltrue;1e-4*ones(1,q)];	% in homogeneous coordinates

Rho = makealbedo(albedotype,r,s);
[M,XX,YY,Z,Ntrue,h,B] = makeimage(f,fx,fy,r,s,A,Ltrueh,Rho);
Morig = M;
M = M + ds*norm(M,'fro')*randn(p,q)/sqrt(p*q);

% Neumann conditions
bdata{1} = -fy(XX(1,:),-B/2); 
bdata{2} = fy(XX(1,:),B/2); 
bdata{3} = -fx(-A/2,YY(:,1)); 
bdata{4} = fx(A/2,YY(:,1)); 
bdata{5} = f(XX(1,round(r/2)),YY(round(s/2),1));

if funind == 3		% clean NaN's in test function 3
	warning('Cleaning NaN''s from data.')
	mm = M(:);
	mm(isnan(mm)) = M(1,1);
	M = reshape(mm,p,q);
	vv = find(isnan(Ntrue(1,:)));
	Ntrue(:,vv) = Ntrue(:,vv-1);
end

figure(1)
surfl(XX,YY,Z)
colormap gray
shading interp
axis equal
set(gca,'fontsize',fsiz)
title('Model surface')

figure(2)
clf
fprintf('displaying images:')
for i = 1:q
	fprintf(' %d',i)
	figure(2)
	subplot(nrow,ncol,i)
	pcolor(imresize(reshape(M(:,i),s,r),displayfactor))
	colormap gray
	shading interp
	axis image
	axis off
	%pause
end
fprintf('\n')
disp('press a key to continue ...'), pause

[U,X,Y,D,N,L,P,Q] = ps3d(M,r,s,A,light2,6,fsiz,bcond,bdata);

if bcond==2
	U(1,1) = nan;
	U(1,end) = nan;
	U(end,1) = nan;
	U(end,end) = nan;
end

PP = fx(X,Y);
QQ = fy(X,Y);
fprintf('norm(Ntrue-N)/norm(Ntrue) = %.2e\n', norm(Ntrue-N,'fro')/norm(Ntrue,'fro'))
fprintf('norm(Ltrue-L)/norm(Ltrue) = %.2e\n', norm(Ltrue-L,'fro')/norm(Ltrue,'fro'))
%fprintf('norm(P-PP)/norm(P) = %.2e\n', norm(P-PP,'fro')/norm(P,'fro'))
%fprintf('norm(Q-QQ)/norm(Q) = %.2e\n', norm(Q-QQ,'fro')/norm(Q,'fro'))
%P = PP; Q = QQ;	% cheating...

fprintf('norm(Rho-D)/norm(Rho) = %.2e\n', norm(Rho-D,'fro')/norm(Rho,'fro'))
fprintf('norm(Z-U)/norm(Z) = %.2e\n', norm(Z-U,'fro')/norm(Z,'fro'))

if show
	figure(3)
	S = surfl(X,Y,U);
	%S = surfl(X,Y,U,[1000;-1000;40],'light');
	set(S(1),'facecolor','texture','Cdata',D,'edgecolor','none')
	colormap gray
	shading interp
	light
	axis equal
	axis off
	set(gca,'fontsize',fsiz)
	title('Reconstruction')
end

figure(4)
surf(X,Y,Z-U)
%title('errore Z-U')
colormap hot
set(gca,'fontsize',fsiz)
title('Reconstruction error')

disp(' ')
disp('to save 3D model: writeply(X,Y,U,repmat(D,1,1,3),''synth'')')
disp('then use an external viewer to display it')
disp('for example: meshlab synth.ply &')

