function writeply(x,y,z,texture,fname)
%WRITEPLY convert .mat surface into .ply file.
%   writeply(z,texture,fileName) converts a surface into a .ply file to
%   visualize it by a 3D viewer/editor like, e.g., MeshLab.
%   x,y,z are the coordinates of the surface to be converted, 
%   texture is the albedo of the surface, fname the file name.

%   A. Concas, R. Dessì, C. Fenu, G. Rodriguez & M. Vanzi
%   Email: concas.anna@gmail.com, richidessi@gmail.com, kate.fenu@unica.it, 
%   rodriguez@unica.it, vanzi@diee.unica.it
%
%   Last revised June, 2021

[mz,nz] = size(z);
[mt, nt, ~] = size(texture);

if (nz ~= nt || mz ~= mt)
	error('something wrong with dimension, texture and z must have the same dimension')
end

fullname = sprintf('%s.ply',fname);
fid = fopen(fullname,'w');

[facce,vertici] = surf2patch(x,y,z);

[nvertici,~] = size(vertici);

[nrfacce,nfacce] = size(facce);

albedor = texture(:,:,1);
albedog = texture(:,:,2);
albedob = texture(:,:,3);
albedor = albedor(:);
albedog = albedog(:);
albedob = albedob(:);

K = albedor;
K(:,2) = albedog;
K(:,3) = albedob;

fprintf(fid,'ply\n');
fprintf(fid,'format ascii 1.0\n');
fprintf(fid,'element vertex %d\n',nvertici);
fprintf(fid,'property float x\n');
fprintf(fid,'property float y\n');
fprintf(fid,'property float z\n');
fprintf(fid,'property uchar red\n');
fprintf(fid,'property uchar green\n');
fprintf(fid,'property uchar blue\n');
fprintf(fid,'element face %d\n',nrfacce);
fprintf(fid,'property list uchar int vertex_index\n');
fprintf(fid,'end_header\n');

vertici = vertici-1;
facce = facce-1;
disp('writing vertices')
fprintf(fid,'%f %f %f %d %d %d\n',[vertici  round(abs(K.*250)) ]');

disp('writing faces')
if nfacce == 3
	fprintf(fid,'3 %d %d %d\n',facce');
elseif nfacce == 4
	fprintf(fid,'4 %d %d %d %d\n',facce');
end  

fclose(fid);

